## Data source types 

::: wellies.data.StaticData

::: wellies.data.CopyData

::: wellies.data.RsyncData

::: wellies.data.LinkData

::: wellies.data.ECFSData

::: wellies.data.GitData

::: wellies.data.MarsData

::: wellies.data.CustomData

## Static Data Store

::: wellies.data.StaticDataStore
